"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createTransportBridge = void 0;
function unidirectionalBridge(transportIn, transportOut) {
    if (!transportIn.registerHandler || !transportOut.send)
        return;
    const handler = (message) => transportOut.send?.(message);
    transportIn.registerHandler(handler);
    return function cleanUp() {
        transportIn.unregisterHandler?.();
    };
}
/**
 * Creates a transport bridge between two transports.
 */
function createTransportBridge(transportA, transportB) {
    let cleanUpAToB;
    let cleanUpBToA;
    return {
        start() {
            cleanUpAToB = unidirectionalBridge(transportA, transportB);
            cleanUpBToA = unidirectionalBridge(transportB, transportA);
        },
        stop() {
            cleanUpAToB?.();
            cleanUpAToB = undefined;
            cleanUpBToA?.();
            cleanUpBToA = undefined;
        },
    };
}
exports.createTransportBridge = createTransportBridge;
