/**
 * Common options for a transport.
 */
export type RPCTransportOptions = {
    /**
     * An optional unique ID to use for the transport. Useful in cases where
     * messages are sent to or received from multiple sources, which causes
     * issues.
     */
    transportId?: string | number;
    /**
     * A filter function that determines if a message should be processed or
     * ignored. Like the `transportId` option, but more flexible to allow for
     * more complex use-cases.
     */
    filter?: () => boolean | undefined;
};
/**
 * Wraps a message in a transport object, if a transport ID is provided.
 */
export declare function rpcTransportMessageOut(data: any, options: Pick<RPCTransportOptions, "transportId">): any;
/**
 * Determines if a message should be ignored, and if not, returns the message
 * too. If the message was wrapped in a transport object, it is unwrapped.
 */
export declare function rpcTransportMessageIn(message: any, options: RPCTransportOptions): [ignore: false, message: any] | [ignore: true];
