import { type Browser, type Chrome } from "browser-namespace";
import { type RPCTransportOptions } from "../transport-utils.js";
import { type RPCTransport } from "../types.js";
type Port = Browser.Runtime.Port | Chrome.runtime.Port;
/**
 * Options for the browser runtime port transport.
 */
export type RPCBrowserRuntimePortTransportOptions = Pick<RPCTransportOptions, "transportId"> & {
    /**
     * A filter function that determines if a message should be processed or
     * ignored. Like the `transportId` option, but more flexible to allow for
     * more complex use-cases.
     *
     * It receives the message and the
     * [`runtime.Port`](https://developer.mozilla.org/en-US/docs/Mozilla/Add-ons/WebExtensions/API/runtime/Port)
     * as arguments. For example, messages can be filtered
     * based on `port.name` or `port.sender`.
     */
    filter?: (message: any, port: Browser.Runtime.Port) => boolean;
};
/**
 * Creates a transport from a browser runtime port. Useful for RPCs
 * in browser extensions, like between content scripts and service workers
 * (background scripts). [Learn more on MDN.](https://developer.mozilla.org/en-US/docs/Mozilla/Add-ons/WebExtensions/API/runtime/Port)
 */
export declare function createTransportFromBrowserRuntimePort(
/**
 * The browser runtime port.
 */
port: Port, 
/**
 * Options for the browser runtime port transport.
 */
options?: RPCBrowserRuntimePortTransportOptions): RPCTransport;
export {};
