"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createTransportFromBrowserRuntimePort = void 0;
const transport_utils_js_1 = require("../transport-utils.js");
/**
 * Creates a transport from a browser runtime port. Useful for RPCs
 * in browser extensions, like between content scripts and service workers
 * (background scripts). [Learn more on MDN.](https://developer.mozilla.org/en-US/docs/Mozilla/Add-ons/WebExtensions/API/runtime/Port)
 */
function createTransportFromBrowserRuntimePort(
/**
 * The browser runtime port.
 */
port, 
/**
 * Options for the browser runtime port transport.
 */
options = {}) {
    const { transportId, filter } = options;
    let transportHandler;
    return {
        send(data) {
            port.postMessage((0, transport_utils_js_1.rpcTransportMessageOut)(data, { transportId }));
        },
        registerHandler(handler) {
            transportHandler = (message, port) => {
                const [ignore, data] = (0, transport_utils_js_1.rpcTransportMessageIn)(message, {
                    transportId,
                    filter: () => filter?.(message, port),
                });
                if (ignore)
                    return;
                handler(data);
            };
            port.onMessage.addListener(transportHandler);
        },
        unregisterHandler() {
            if (transportHandler)
                port.onMessage.removeListener(transportHandler);
        },
    };
}
exports.createTransportFromBrowserRuntimePort = createTransportFromBrowserRuntimePort;
// TODO: browser runtime port transport tests.
