/// <reference lib="webworker" />
import { type RPCTransportOptions } from "../transport-utils.js";
import { type RPCTransport } from "../types.js";
/**
 * Options for the message port transport.
 */
export type RPCMessagePortTransportOptions = Pick<RPCTransportOptions, "transportId"> & {
    /**
     * A filter function that determines if a message should be processed or
     * ignored. Like the `transportId` option, but more flexible to allow for
     * more complex use-cases.
     *
     * It receives the
     * [`MessageEvent`](https://developer.mozilla.org/en-US/docs/Web/API/MessageEvent)
     * object as its only argument. For example, messages can be filtered
     * based on `event.origin` or `event.source`.
     */
    filter?: (event: MessageEvent) => boolean;
    /**
     * The remote port to send messages to through `postMessage(message)`.
     */
    remotePort?: MessagePort | Window | Worker | ServiceWorker | Client | BroadcastChannel;
};
/**
 * Creates a transport from objects that support `postMessage(message)`
 * and `addEventListener("message", listener)`. This includes `Window`,
 * `Worker`, `MessagePort`, and `BroadcastChannel`.
 *
 * This is useful for RPCs between, among other things, iframes or workers.
 */
export declare function createTransportFromMessagePort(
/**
 * The local port that will receive and handled "message" events
 * through `addEventListener("message", listener)`. If the `remotePort`
 * option is omitted, it will also be used to send messages through
 * `postMessage(message)`.
 */
port: MessagePort | Window | Worker | ServiceWorkerContainer | BroadcastChannel, 
/**
 * Options for the message port transport.
 */
options?: RPCMessagePortTransportOptions): RPCTransport;
