/// <reference lib="webworker" />
import { createTransportFromMessagePort, } from "./message-port.js";
/**
 * Creates a transport to communicate with a
 * [`Worker`](https://developer.mozilla.org/en-US/docs/Web/API/Worker)
 * from the parent context.
 *
 * The target worker must must use `createWorkerParentTransport` with a matching
 * `transportId` or `filter` option (if set).
 *
 * @example
 *
 * ```ts
 * const rpc = createRPC<ParentSchema, WorkerSchema>({
 *   transport: createWorkerTransport(worker),
 *   // ...
 * });
 */
export function createWorkerTransport(
/**
 * The worker instance to create a transport from.
 */
worker, 
/**
 * Options for the worker transport.
 */
options) {
    return createTransportFromMessagePort(worker, options);
}
/**
 * Creates a transport to communicate with the parent context from a
 * [`Worker`](https://developer.mozilla.org/en-US/docs/Web/API/Worker).
 *
 * The parent context must use `createWorkerTransport` with a matching
 * `transportId` or `filter` option (if set).
 *
 * @example
 *
 * ```ts
 * const rpc = createRPC<WorkerSchema, ParentSchema>({
 *   transport: createWorkerParentTransport(),
 *   // ...
 * });
 */
export function createWorkerParentTransport(
/**
 * Options for the worker parent transport.
 */
options) {
    return createTransportFromMessagePort(self, options);
}
